@@ -80,6 +80,7 @@ class AB_Base:
         self.my_user_id = self.user_id()
 
         ignore_read = False
+        self.init_action_taken = "none"
 
         if self.kwargs.get("init_action", "read") in ("read", "readorcreate") and self.id is None:
             # I didn't get an ID
@@ -87,11 +88,15 @@ class AB_Base:
                 # I searched for and found (or not) a result
                 self.id = self.search()
 
+                self.init_action_taken = "read"
+
                 self.logger.info("Found ID : {} on search.".format(self.id))
 
                 if self.kwargs.get("init_action", "read") == "readorcreate" and self.id is None:
                     # If I didn't find a result and it's requested, let's create based on the data.
                     self.id, self.datum = self.create()
+
+                    self.init_action_taken = "create"
                     # Don't try to read twice, that's ridiculous
                     ignore_read = True
             else:
@@ -99,8 +104,10 @@ class AB_Base:
 
         if self.kwargs.get("init_action", "read") == "read" and self.id is not None and ignore_read is False:
             self.id, self.datum = self.get()
+            self.init_action_taken = "read"
         elif self.kwargs.get("init_action", "read") == "create":
             self.id, self.datum = self.create()
+            self.init_action_taken = "create"
 
     def user_id(self):
 
@@ -262,7 +269,7 @@ class AB_Base:
 
         post_data = {self.name: self.serialize(full_json=False)}
 
-        self.logger.debug(post_data)
+        self.logger.debug("Create Post Data: {}".format(json.dumps(post_data, default=str)))
 
         try:
             data_request = requests.post(control_endpoint, headers=self.headers, json=post_data)
@@ -428,6 +435,8 @@ class AB_Base:
                     else:
                         new_val.append(x)
 
+                to_serialize[key] = new_val
+
         # Make Requested Null Keys
         for nk in self.create_null_keys:
             if nk not in to_serialize:
